var plplot_8h =
[
    [ "PLOptionTable", "structPLOptionTable.html", "structPLOptionTable" ],
    [ "PLGraphicsIn", "structPLGraphicsIn.html", "structPLGraphicsIn" ],
    [ "PLWindow", "structPLWindow.html", "structPLWindow" ],
    [ "PLDisplay", "structPLDisplay.html", "structPLDisplay" ],
    [ "PLfGrid", "structPLfGrid.html", "structPLfGrid" ],
    [ "PLfGrid2", "structPLfGrid2.html", "structPLfGrid2" ],
    [ "PLcGrid", "structPLcGrid.html", "structPLcGrid" ],
    [ "PLcGrid2", "structPLcGrid2.html", "structPLcGrid2" ],
    [ "PLColor", "structPLColor.html", "structPLColor" ],
    [ "PLControlPt", "structPLControlPt.html", "structPLControlPt" ],
    [ "PLBufferingCB", "structPLBufferingCB.html", "structPLBufferingCB" ],
    [ "PLLabelDefaults", "structPLLabelDefaults.html", "structPLLabelDefaults" ],
    [ "plf2ops_t", "structplf2ops__t.html", "structplf2ops__t" ],
    [ "plbuffer", "structplbuffer.html", "structplbuffer" ],
    [ "BASE_CONT", "plplot_8h.html#a615d5bba089363ae37df2a6b33fac010", null ],
    [ "BRAINDEAD", "plplot_8h.html#a397833bd03deddc81a012b416c10bc8f", null ],
    [ "DRAW_LINEX", "plplot_8h.html#abc232a5d2bdcfe6d917d28b1d0113261", null ],
    [ "DRAW_LINEXY", "plplot_8h.html#ab0c68fc37f1b7d44b612136a9447a26a", null ],
    [ "DRAW_LINEY", "plplot_8h.html#a6b90cdc3b439f3c31a19c9b610732b96", null ],
    [ "DRAW_SIDES", "plplot_8h.html#a97f8c99c7977160450c93302222ff923", null ],
    [ "FACETED", "plplot_8h.html#a73593859d45942fe004d7bbf925ef770", null ],
    [ "GRID_CSA", "plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa", null ],
    [ "GRID_DTLI", "plplot_8h.html#abeff949898412780654cf7cca55561b2", null ],
    [ "GRID_NNAIDW", "plplot_8h.html#ac863b08f442af857a166e36ad4721058", null ],
    [ "GRID_NNI", "plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c", null ],
    [ "GRID_NNIDW", "plplot_8h.html#aea4b4b399c7eff90105f16be688f869d", null ],
    [ "GRID_NNLI", "plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2", null ],
    [ "MAG_COLOR", "plplot_8h.html#aabfa89cd7c78947bb0bc95a48b64dac3", null ],
    [ "MESH", "plplot_8h.html#a713bfb80c38c2af8800c6425a34a8376", null ],
    [ "ONEW2B", "plplot_8h.html#a6e483ccfaad62129bfd0c7f60ff58d9a", null ],
    [ "ONEW2D", "plplot_8h.html#ac40cfbf950fe5727d3de6d31abc6c189", null ],
    [ "PL_BIN_CENTRED", "plplot_8h.html#af3461c53e333e2bbe43b64bf21057aa1", null ],
    [ "PL_BIN_DEFAULT", "plplot_8h.html#aee12fc4bc22f8e999ed745d1df31c795", null ],
    [ "PL_BIN_NOEMPTY", "plplot_8h.html#ac84d30741184027686cbac2707d21123", null ],
    [ "PL_BIN_NOEXPAND", "plplot_8h.html#a297710e408c30539e95fd20aa87f9997", null ],
    [ "PL_COLORBAR_BACKGROUND", "plplot_8h.html#a1886a7e2aee9c95828fca4eda4261ffe", null ],
    [ "PL_COLORBAR_BOUNDING_BOX", "plplot_8h.html#ad4a664cdb2585e4c37fe1a3b07bafd6c", null ],
    [ "PL_COLORBAR_CAP_HIGH", "plplot_8h.html#a42c124d5c2e9932e3d27d1dd347d1b17", null ],
    [ "PL_COLORBAR_CAP_LOW", "plplot_8h.html#ac2879db42d0c9d963cb2d3a74e953ec4", null ],
    [ "PL_COLORBAR_CAP_NONE", "plplot_8h.html#a2afd94d27753eaa659949bad09b9faea", null ],
    [ "PL_COLORBAR_GRADIENT", "plplot_8h.html#aa339ae32d9e3d5cdbd953040d2bfe46a", null ],
    [ "PL_COLORBAR_IMAGE", "plplot_8h.html#a54d6629ba95fb6413fbf6451f16d6e65", null ],
    [ "PL_COLORBAR_LABEL_BOTTOM", "plplot_8h.html#aabc96a420c830731f6ece5694a9adc60", null ],
    [ "PL_COLORBAR_LABEL_LEFT", "plplot_8h.html#ac81ae9a4c7016376c8904cbdc6f29aee", null ],
    [ "PL_COLORBAR_LABEL_RIGHT", "plplot_8h.html#a83fb83c49b854017aeb18c2160911a92", null ],
    [ "PL_COLORBAR_LABEL_TOP", "plplot_8h.html#a38466c6fea905d6221e6a338f71d9b5b", null ],
    [ "PL_COLORBAR_ORIENT_BOTTOM", "plplot_8h.html#a3515daea0a292f5471fa2ad275990b09", null ],
    [ "PL_COLORBAR_ORIENT_LEFT", "plplot_8h.html#ae9a9558d97dfdb6d9fd92fcc70e28678", null ],
    [ "PL_COLORBAR_ORIENT_RIGHT", "plplot_8h.html#ac6cb8a5f5563286a76b84f3c8ddeab34", null ],
    [ "PL_COLORBAR_ORIENT_TOP", "plplot_8h.html#a3df04608a202ec76624bbc0036cb1b6c", null ],
    [ "PL_COLORBAR_SHADE", "plplot_8h.html#aea4a4532c00c254591c5a58ca92b5875", null ],
    [ "PL_COLORBAR_SHADE_LABEL", "plplot_8h.html#a58a4cf16afb401d8c65f944770c53d49", null ],
    [ "PL_DRAWMODE_DEFAULT", "plplot_8h.html#ac5eeff3ef245c5b23310ba17946a284a", null ],
    [ "PL_DRAWMODE_REPLACE", "plplot_8h.html#a4ae91e69b166f8e0b208bf5ddc1173f8", null ],
    [ "PL_DRAWMODE_UNKNOWN", "plplot_8h.html#a88ed02445de7f47970e9b5d21c4719d5", null ],
    [ "PL_DRAWMODE_XOR", "plplot_8h.html#a8fe9ae3ea64f7c6b720e378ea759dc8f", null ],
    [ "PL_FCI_BOLD", "plplot_8h.html#abb99575234e2ce19c89f844684491983", null ],
    [ "PL_FCI_FAMILY", "plplot_8h.html#acb6b245aaed9f9661123fee7abeb6a9f", null ],
    [ "PL_FCI_HEXDIGIT_MASK", "plplot_8h.html#a2a22a6ef2d6ca75b687d542a71547ddf", null ],
    [ "PL_FCI_HEXPOWER_IMPOSSIBLE", "plplot_8h.html#a23dd416cb2d438844f986aa1d2e3c187", null ],
    [ "PL_FCI_HEXPOWER_MASK", "plplot_8h.html#ab912c7efb044fda08307c1d9626dfa90", null ],
    [ "PL_FCI_IMPOSSIBLE", "plplot_8h.html#a788353da464c0933acae712eed0eada8", null ],
    [ "PL_FCI_ITALIC", "plplot_8h.html#af2422f894b3c18285a52d0e0ae5ed5f0", null ],
    [ "PL_FCI_MARK", "plplot_8h.html#af74899890d487af9aacd1b1ab62cffb8", null ],
    [ "PL_FCI_MEDIUM", "plplot_8h.html#a17be14f72a7e52c1e81571643da91a1a", null ],
    [ "PL_FCI_MONO", "plplot_8h.html#a47ef514965ea1c4045e43abb85d82909", null ],
    [ "PL_FCI_OBLIQUE", "plplot_8h.html#a7b7df74d045a46cb0f96f3524d3396d8", null ],
    [ "PL_FCI_SANS", "plplot_8h.html#ae0dac4c7803a98b70eda4e0dfbe2c41f", null ],
    [ "PL_FCI_SCRIPT", "plplot_8h.html#a24b37d7e840722ba23305ff91b0232a7", null ],
    [ "PL_FCI_SERIF", "plplot_8h.html#ac50e4663acf81c75285da6c9d1d7df1e", null ],
    [ "PL_FCI_STYLE", "plplot_8h.html#ac55bfe409e42314412f2a130595610c7", null ],
    [ "PL_FCI_SYMBOL", "plplot_8h.html#af4c902b64e13f552fcc2793172b0e4c7", null ],
    [ "PL_FCI_UPRIGHT", "plplot_8h.html#a9f9d1c25dbb88256a528b6e307ac2e13", null ],
    [ "PL_FCI_WEIGHT", "plplot_8h.html#a56a2e7aff93cc40a833762f13d95e5a1", null ],
    [ "PL_HIST_DEFAULT", "plplot_8h.html#a9936c75a739fccdea85dca8085e5ff5c", null ],
    [ "PL_HIST_IGNORE_OUTLIERS", "plplot_8h.html#a2932c488ba81c8a43e0d1df8b0eae90e", null ],
    [ "PL_HIST_NOEMPTY", "plplot_8h.html#ad90d49c58811c225f9b40fe16b2c5269", null ],
    [ "PL_HIST_NOEXPAND", "plplot_8h.html#ad045227a60fd1b7a6ba7484cbb9e9abf", null ],
    [ "PL_HIST_NOSCALING", "plplot_8h.html#a114d7b8dffa03fd0dcdf52c336ff0241", null ],
    [ "PL_LEGEND_BACKGROUND", "plplot_8h.html#a4b6b34d5a9d146919741267b91f8cf78", null ],
    [ "PL_LEGEND_BOUNDING_BOX", "plplot_8h.html#a7de3e124cb2c9d5aa7c9dc85efc70b72", null ],
    [ "PL_LEGEND_COLOR_BOX", "plplot_8h.html#a55f9fd02e3c80518f175dbd9b2c135bb", null ],
    [ "PL_LEGEND_LINE", "plplot_8h.html#a70f997ff03bb62308ec6e6b82783d6ee", null ],
    [ "PL_LEGEND_NONE", "plplot_8h.html#a39430311ce223e88826f0c92864eeba3", null ],
    [ "PL_LEGEND_ROW_MAJOR", "plplot_8h.html#a67acdb622747723dd63d61c8db77ec3f", null ],
    [ "PL_LEGEND_SYMBOL", "plplot_8h.html#af9035c908614e1db71828eb2de742597", null ],
    [ "PL_LEGEND_TEXT_LEFT", "plplot_8h.html#ae8e673b57f1894dce563b5e3680f04d9", null ],
    [ "PL_MAXKEY", "plplot_8h.html#a44c035ac35674a4596e8e8ab9f01a556", null ],
    [ "PL_MAXWINDOWS", "plplot_8h.html#ad4c0f054dbc15c9e5478c857912c35f8", null ],
    [ "PL_NOTSET", "plplot_8h.html#a33abbe5268cf992ac1a9ed78c169d630", null ],
    [ "PL_OPT_ARG", "plplot_8h.html#a7e09f1097e789e32c464ef427864b381", null ],
    [ "PL_OPT_BOOL", "plplot_8h.html#a949faa90745b619d61e7802ded01a8dd", null ],
    [ "PL_OPT_DISABLED", "plplot_8h.html#abc3c243c26445135d14eb219881e0966", null ],
    [ "PL_OPT_ENABLED", "plplot_8h.html#a47bbd4447a07ca7ae2d1dbeb2dbc3a00", null ],
    [ "PL_OPT_FLOAT", "plplot_8h.html#aeee44ed62e55d68e88d898c153043725", null ],
    [ "PL_OPT_FUNC", "plplot_8h.html#a568b36886dddaa10bdc8f850279fc778", null ],
    [ "PL_OPT_INT", "plplot_8h.html#a8ee2e2be02655057ab68049f9b7c8e55", null ],
    [ "PL_OPT_INVISIBLE", "plplot_8h.html#a9fed284e2dad916ce20aa512912e66ad", null ],
    [ "PL_OPT_NODELETE", "plplot_8h.html#a3d2bbd2fc483c213fa2e44e34de74ed2", null ],
    [ "PL_OPT_STRING", "plplot_8h.html#ac95d3968abf030b28ebe3bc0437bc6a6", null ],
    [ "PL_PARSE_FULL", "plplot_8h.html#a14479e41f2f0a4dbdb5a683497e861a2", null ],
    [ "PL_PARSE_NODASH", "plplot_8h.html#aeca83fa81659438865c63b6b4f46108e", null ],
    [ "PL_PARSE_NODELETE", "plplot_8h.html#a8f24dc82fc35e1f787ec01d02b6a4534", null ],
    [ "PL_PARSE_NOPROGRAM", "plplot_8h.html#af8f39dec3f5a833d10a432b8c44482ea", null ],
    [ "PL_PARSE_OVERRIDE", "plplot_8h.html#a89bd94ba9fbb2c3ab8118b3eeedb9ae9", null ],
    [ "PL_PARSE_PARTIAL", "plplot_8h.html#ad22d9d607ab5f334a2df5f5dd74f98ff", null ],
    [ "PL_PARSE_QUIET", "plplot_8h.html#a929d833ef4808699abce4588635bc657", null ],
    [ "PL_PARSE_SHOWALL", "plplot_8h.html#a07c13cf8ba54ab33c7926207de969465", null ],
    [ "PL_PARSE_SKIP", "plplot_8h.html#a1b2086d2e30c2cc6e9856269b8e46c00", null ],
    [ "PL_POSITION_BOTTOM", "plplot_8h.html#a070f403a976e42378aad22e51d1a5285", null ],
    [ "PL_POSITION_INSIDE", "plplot_8h.html#aac38c988f1ba35e2e861fe87368a17b5", null ],
    [ "PL_POSITION_LEFT", "plplot_8h.html#aea8b06633788da6fbc6988f63d6ab0e5", null ],
    [ "PL_POSITION_OUTSIDE", "plplot_8h.html#a51a7b6a259eb2137fa1d3f63f2bc3513", null ],
    [ "PL_POSITION_RIGHT", "plplot_8h.html#abbe12ba62ad2169d23202cbcd6514f02", null ],
    [ "PL_POSITION_SUBPAGE", "plplot_8h.html#a3f53fc4e08007a1ca37b22c9f659a500", null ],
    [ "PL_POSITION_TOP", "plplot_8h.html#a61ba83ff66013b10ec81bfb0e197f0cc", null ],
    [ "PL_POSITION_VIEWPORT", "plplot_8h.html#a9dc2049533b981570e5c3bff8a54202b", null ],
    [ "pl_setcontlabelformat", "plplot_8h.html#a759b301d598ed5606f95d7f3cc44c9f7", null ],
    [ "pl_setcontlabelparam", "plplot_8h.html#aabf62307ee5da33616fb41cdf94241ec", null ],
    [ "PL_UNUSED", "plplot_8h.html#a7d5497a8bc266dc65d84f05403965fbd", null ],
    [ "PL_X_AXIS", "plplot_8h.html#a56a5fd49ef1fdbddaea6796d554a8ea2", null ],
    [ "PL_Y_AXIS", "plplot_8h.html#a1112e4818b4e23d202362016b0f248e6", null ],
    [ "PL_Z_AXIS", "plplot_8h.html#acdc5bdf8af5f76efe849b1e3367e8302", null ],
    [ "pladv", "plplot_8h.html#ad2490b31759e486f52f36acc1d346e4e", null ],
    [ "plarc", "plplot_8h.html#a896d0adf8f8b516b75fd79dd07d94a32", null ],
    [ "plaxes", "plplot_8h.html#a9140da57e3d272cb8db2541116b660d2", null ],
    [ "plbin", "plplot_8h.html#adbe5e12f749fd2f03f62e4aabd0952d8", null ],
    [ "plbop", "plplot_8h.html#a36146b1eb81a5b362c484ac79aad0d36", null ],
    [ "plbox", "plplot_8h.html#af55a7619d9dc46406190e135ba1a2df2", null ],
    [ "plbox3", "plplot_8h.html#a176fa792ce37ba7708e257739db99242", null ],
    [ "plbtime", "plplot_8h.html#af90c75a8ebae3b6d85f9b03c8f03d520", null ],
    [ "plcalc_world", "plplot_8h.html#a591cb7ee0cde82ce351668aec53dd977", null ],
    [ "plclear", "plplot_8h.html#a63bd1070520beaff11ae084e68bfa42f", null ],
    [ "plcol0", "plplot_8h.html#abe182603da58d374804b7e0e31bb64f5", null ],
    [ "plcol1", "plplot_8h.html#a198b30552fe0d9e3a2de4727e09fa7f4", null ],
    [ "plcolorbar", "plplot_8h.html#ac08f1d4f5ca20c5e4840aa01fb7e2f6c", null ],
    [ "plconfigtime", "plplot_8h.html#a7826895e589cd9c52a66ee1adae63696", null ],
    [ "plcont", "plplot_8h.html#a900cfb770c6f4dbeb162c6c4aed35b13", null ],
    [ "plcpstrm", "plplot_8h.html#ac9f42bf9fcaf791c72b0c1152d8c2727", null ],
    [ "plctime", "plplot_8h.html#a62b48f8c8943b09d19f6bbc75ceff1e6", null ],
    [ "plend", "plplot_8h.html#aee9aeb2fb5c1888c307b74910dab6800", null ],
    [ "plend1", "plplot_8h.html#ad9122365d79d7b45c78da65c09f7e1c9", null ],
    [ "plenv", "plplot_8h.html#a27c648f17a51851ba7a3538d20a98f48", null ],
    [ "plenv0", "plplot_8h.html#a4d74b2c507e688f57bf0bb82a3608d69", null ],
    [ "pleop", "plplot_8h.html#a0cba424c4c58ca5b60b474917d42d2b5", null ],
    [ "plerrx", "plplot_8h.html#a1267f751a55fbf9af59a9f5cb66241c3", null ],
    [ "plerry", "plplot_8h.html#a07f65d6478ffa4353de099f7a250706b", null ],
    [ "PLESC_ALLOC_NCOL", "plplot_8h.html#ae87f50d83b1fa81c85e641ff1603b087", null ],
    [ "PLESC_APPEND_BUFFER", "plplot_8h.html#a9f071fd6195ce50d251d76e9e19ebe1a", null ],
    [ "PLESC_ARC", "plplot_8h.html#ac183a5dea6e2d74c914fbfd683707851", null ],
    [ "PLESC_BEGIN_TEXT", "plplot_8h.html#ad60423577a77dfdc57cffefcb95fdcd8", null ],
    [ "PLESC_CLEAR", "plplot_8h.html#aa499059ba6f588b9034a61d071e9caa7", null ],
    [ "PLESC_CONTROL_CHAR", "plplot_8h.html#a1c35044344b3eb8bb850f25d7dc3f1b8", null ],
    [ "PLESC_DASH", "plplot_8h.html#ab914590b71216f57f420a85083efa0ac", null ],
    [ "PLESC_DEV2PLCOL", "plplot_8h.html#a19eb29f519ab16f112122a5471800e49", null ],
    [ "PLESC_DEVINIT", "plplot_8h.html#a63307df7061d9e7dd3e32ce26edb9839", null ],
    [ "PLESC_DI", "plplot_8h.html#a85d3543f7602f5dd6d883dfdc1a0bd29", null ],
    [ "PLESC_DOUBLEBUFFERING", "plplot_8h.html#ae0ba67569d3c270f7161e72c6f5cb514", null ],
    [ "PLESC_DOUBLEBUFFERING_DISABLE", "plplot_8h.html#aa832b81650fc3ea47048d5882f089797", null ],
    [ "PLESC_DOUBLEBUFFERING_ENABLE", "plplot_8h.html#afa4d34c5d6c58fcf3d7ef4d027566314", null ],
    [ "PLESC_DOUBLEBUFFERING_QUERY", "plplot_8h.html#a19824499a04b0568256bbf3c27ae2b9e", null ],
    [ "PLESC_EH", "plplot_8h.html#a5982ba3fe561d3c0060b58fa4f40479a", null ],
    [ "PLESC_END_RASTERIZE", "plplot_8h.html#ae0382fba5d32e979cb384e714afa1518", null ],
    [ "PLESC_END_TEXT", "plplot_8h.html#a364fdd01ecc2c39ce6bf9068dcf55792", null ],
    [ "PLESC_EXPOSE", "plplot_8h.html#a04ed603d88adb3cd41dafeb07df6eabf", null ],
    [ "PLESC_FILL", "plplot_8h.html#ab9b25e6e06dd0d6808371db0ddc0122a", null ],
    [ "PLESC_FIXASPECT", "plplot_8h.html#a12543c8963759e9e89f2aeb6443dafce", null ],
    [ "PLESC_FLUSH", "plplot_8h.html#a77b55167b45bce03588d2893c466c368", null ],
    [ "PLESC_FLUSH_REMAINING_BUFFER", "plplot_8h.html#ae9b11f35267bde0d224413a306edce35", null ],
    [ "PLESC_GETBACKEND", "plplot_8h.html#ac4ab70a8f75aa95eba0de158d12f0d39", null ],
    [ "PLESC_GETC", "plplot_8h.html#a0b36e6a122fbc4a47ff8ad9964f8623e", null ],
    [ "PLESC_GRADIENT", "plplot_8h.html#a58e75b2debc5ab66b18e0657d5e8bec0", null ],
    [ "PLESC_GRAPH", "plplot_8h.html#a9f9b24c00dc6fe18f16e4a29110d7b43", null ],
    [ "PLESC_HAS_TEXT", "plplot_8h.html#a15ec6c98c5588c218820831631daed82", null ],
    [ "PLESC_IMAGE", "plplot_8h.html#a7e3519bc3357c32808f4a40040e609f2", null ],
    [ "PLESC_IMAGEOPS", "plplot_8h.html#ae89d843559d5d03418cb91d9b161334a", null ],
    [ "PLESC_IMPORT_BUFFER", "plplot_8h.html#a14af57e7de42d1649bae2faed3b777c4", null ],
    [ "PLESC_MODEGET", "plplot_8h.html#a0e988a4161665369dd1e2e0973a0897d", null ],
    [ "PLESC_MODESET", "plplot_8h.html#ab82e66ba552dd95fd67c63a4ad8af76a", null ],
    [ "PLESC_PL2DEVCOL", "plplot_8h.html#a13460c5799a6e0d9f9d2374bcd304407", null ],
    [ "PLESC_REDRAW", "plplot_8h.html#afc62814c6cba9cfcfa58239d29e70a8a", null ],
    [ "PLESC_RESIZE", "plplot_8h.html#ab00b3464c4d58d86649631e3113a6723", null ],
    [ "PLESC_SET_COMPRESSION", "plplot_8h.html#a3385d16b283bcad8ca9b25accd538986", null ],
    [ "PLESC_SET_LPB", "plplot_8h.html#afcdd11d53ce7e52d751f08d708ae301c", null ],
    [ "PLESC_SET_RGB", "plplot_8h.html#a85e4f9d6bb3b679fb11b37c1c46837d0", null ],
    [ "PLESC_SETBGFG", "plplot_8h.html#a4449949f5281a60c54a7243dff2e1d89", null ],
    [ "PLESC_START_RASTERIZE", "plplot_8h.html#a37f97e612914d22b55502c4fc5b2e22e", null ],
    [ "PLESC_SWIN", "plplot_8h.html#ad0bc9a1a9333fcadecf61263761b7409", null ],
    [ "PLESC_TEXT", "plplot_8h.html#a15ab7e866686a787b33fa38dbd9fc636", null ],
    [ "PLESC_TEXT_CHAR", "plplot_8h.html#a944d357f5952fdad522b30f01c7d48b9", null ],
    [ "PLESC_XORMOD", "plplot_8h.html#ad0f128389461f7249f2e627dba34dd90", null ],
    [ "plfamadv", "plplot_8h.html#a964d8c7c1f00a1c5d0bab7a6d51f4fde", null ],
    [ "plfill", "plplot_8h.html#a10221007d2c08a7117a70abab63dca51", null ],
    [ "plfill3", "plplot_8h.html#ad51faec84e8ab250bfdd2cdbea9bd331", null ],
    [ "PLFLT_MAX", "plplot_8h.html#a83342f0fa1e35b8979af38fb349ae5ed", null ],
    [ "PLFLT_MIN", "plplot_8h.html#a3d84581230aacab980c3b57c09ec0ab9", null ],
    [ "plflush", "plplot_8h.html#ae58d2db18a9da35dc75fa895fd9c6fcc", null ],
    [ "plfont", "plplot_8h.html#a97607eb1064d82090f15c0ee2390c45a", null ],
    [ "plfontld", "plplot_8h.html#a04be3bb74b27838f83190c31ed82cc55", null ],
    [ "plgchr", "plplot_8h.html#a1fb73af49c9abb537c88ea393752155e", null ],
    [ "plgcmap1_range", "plplot_8h.html#af45063acaef7672d33f91d358e8819cc", null ],
    [ "plgcol0", "plplot_8h.html#ad1c197bc82bbf5f239c00e56efe9a794", null ],
    [ "plgcol0a", "plplot_8h.html#aa50fe6e48a8a48e484d0a4f262c71156", null ],
    [ "plgcolbg", "plplot_8h.html#af3e0cb65c7508fcab65794cf7dc0bbee", null ],
    [ "plgcolbga", "plplot_8h.html#ad25e012477db10ea1f90756fb6208303", null ],
    [ "plgcompression", "plplot_8h.html#ad5a7e890ec11e05b1f5d430eec5751ee", null ],
    [ "plgdev", "plplot_8h.html#a55164c54e6208aa665129e950963da2c", null ],
    [ "plgdidev", "plplot_8h.html#a3858e982a9c0b369fcd3cc12d7b12e59", null ],
    [ "plgdiori", "plplot_8h.html#a4480b3c945c92a81912063a9218ccfef", null ],
    [ "plgdiplt", "plplot_8h.html#a1158e56e4321e7570ca83f6d2bd08345", null ],
    [ "plgdrawmode", "plplot_8h.html#a55d10b752101ce0a68aaf9eb1e20283f", null ],
    [ "plgfam", "plplot_8h.html#ad7c9cfedfc5a36fcd675e30f92f60fb1", null ],
    [ "plgfci", "plplot_8h.html#a015820318be8e09a9664a9e540fcbd46", null ],
    [ "plgfnam", "plplot_8h.html#a445776ffaf078452f9171468e067cbb6", null ],
    [ "plgfont", "plplot_8h.html#a27c0a3c27f2a1ca64fe978086c86e21f", null ],
    [ "plglevel", "plplot_8h.html#a947cb023f2648b03f042576690209482", null ],
    [ "plgpage", "plplot_8h.html#afb6efc36c176f36538d4c186d072a216", null ],
    [ "plgra", "plplot_8h.html#a4d47a7b1078298c9b8ae22ab1fcec98a", null ],
    [ "plgradient", "plplot_8h.html#a568e78dcd391b4433859b890dadd4d9d", null ],
    [ "plgriddata", "plplot_8h.html#aaae873adc73393d0ddb5fd9a2bb45f55", null ],
    [ "plgspa", "plplot_8h.html#a2eedb4af19a32fa71ad9502c3ff3a9b9", null ],
    [ "plgstrm", "plplot_8h.html#a01686a7fe5b616111be053559e38ac4d", null ],
    [ "plgver", "plplot_8h.html#a25f066a9f0bcde8a84b916f851c934e9", null ],
    [ "plgvpd", "plplot_8h.html#a72115cfeb56478b5013f5255f56e40f9", null ],
    [ "plgvpw", "plplot_8h.html#a89a25f49551295ebaa7659891310b801", null ],
    [ "plgxax", "plplot_8h.html#a4b6826699337d378e9afd1f78ee7ab56", null ],
    [ "plgyax", "plplot_8h.html#af9f80e861f700933d9a6fc15a5819e20", null ],
    [ "plgzax", "plplot_8h.html#ab32f3724f9d1c43e8377f5e18663feb7", null ],
    [ "plhist", "plplot_8h.html#a3bdf138d9d1eb9ceacbebf7d3102a91e", null ],
    [ "plhlsrgb", "plplot_8h.html#a7434c36a94f5227381b8516a6bcbb820", null ],
    [ "plimage", "plplot_8h.html#a0dd73bcea5e0252ea3bac8a9738df485", null ],
    [ "plimagefr", "plplot_8h.html#ad5f15675f7917b48ab8baccbbd6f5406", null ],
    [ "plinit", "plplot_8h.html#a1301f8774e801284400f57b513d26300", null ],
    [ "PLINT_MIN", "plplot_8h.html#a2051a514e3b3b49d1518f5c0004ecf42", null ],
    [ "pljoin", "plplot_8h.html#ab20325bf48b4b15b9513e38862e858c6", null ],
    [ "pllab", "plplot_8h.html#a5b2cc40d2ebfe0516a855bf94545ebdf", null ],
    [ "pllegend", "plplot_8h.html#a24934313f195bd9be45ea6269c488068", null ],
    [ "pllightsource", "plplot_8h.html#a298751e5ef41696842b542ad92ca6bba", null ],
    [ "plline", "plplot_8h.html#ab1e6d3fe50dfbda05b419be4ce2052b2", null ],
    [ "plline3", "plplot_8h.html#ad3a891ae7d8092eef6afbdd75b775885", null ],
    [ "pllsty", "plplot_8h.html#a92c6f5898168b542f4dc9b0dee69832c", null ],
    [ "plmap", "plplot_8h.html#a0f8e566fd2a93bf828220f85ce8a0082", null ],
    [ "plmapfill", "plplot_8h.html#a195d7a844dbb92a8f22001ec7c7af0d6", null ],
    [ "plmapline", "plplot_8h.html#a3f35026b66694311152c960424c4262a", null ],
    [ "plmapstring", "plplot_8h.html#a7f527daa07872e6b78010ea7d672e08c", null ],
    [ "plmaptex", "plplot_8h.html#a1e772d703253ac38dd80acadcc6b9b6b", null ],
    [ "plmeridians", "plplot_8h.html#ac3173de283e0221191f9e2135799fc4a", null ],
    [ "plmesh", "plplot_8h.html#aefd07a6d456b4ba015defdcb92eec185", null ],
    [ "plmeshc", "plplot_8h.html#aa81ce26dbf38805a61dad659e74a03e5", null ],
    [ "plmkstrm", "plplot_8h.html#acd26e5b27384f8ec5d44e41da906f68a", null ],
    [ "plmtex", "plplot_8h.html#aea8b2357c54cbeb5684fd5dc07969f81", null ],
    [ "plmtex3", "plplot_8h.html#a624c8069961974c22666a0f030fd950c", null ],
    [ "plot3d", "plplot_8h.html#a81659c151bbdac841e21787c4c0b9e2f", null ],
    [ "plot3dc", "plplot_8h.html#ac6331e4c060c22bb6d2b7a3f18927a26", null ],
    [ "plot3dcl", "plplot_8h.html#a6a3d8b43d766f770458376a19d44128a", null ],
    [ "plparseopts", "plplot_8h.html#a7f34f76bda1bd5160d110e6f0ea314a5", null ],
    [ "plpat", "plplot_8h.html#a02b63d4b5fa44eaadfabf992712d3694", null ],
    [ "plpath", "plplot_8h.html#a055c4c882ea933b52e5d873f56c6a556", null ],
    [ "plpoin", "plplot_8h.html#a391bfdb36f44d04462ff5e486c2eb5c5", null ],
    [ "plpoin3", "plplot_8h.html#a2e8604cbcbccb3f5244cc996515a429d", null ],
    [ "plpoly3", "plplot_8h.html#afa94b6d39d92d9b1d84a46bd936b97ad", null ],
    [ "plprec", "plplot_8h.html#ad48f6311e95614708d1be02ee03a5aa8", null ],
    [ "plpsty", "plplot_8h.html#a270aee0c597b273928187bfe199a991e", null ],
    [ "plptex", "plplot_8h.html#a318c60235829b3f3f238e6f9e447f9d4", null ],
    [ "plptex3", "plplot_8h.html#a3a7796925a5651e0cecface95141f896", null ],
    [ "plrandd", "plplot_8h.html#adb71005b1af64e69fc75a4ebea70de3e", null ],
    [ "plreplot", "plplot_8h.html#af1d7cf8090a64f1e8c7567f27c0250fb", null ],
    [ "plrgbhls", "plplot_8h.html#a32f3be36cc79bd7316d3556d0854a7b8", null ],
    [ "plschr", "plplot_8h.html#a033d5d483cb260ff6d3b2460f711a81e", null ],
    [ "plscmap0", "plplot_8h.html#aaaa6ee5b8b7f5d382fbf3d3f9abfe504", null ],
    [ "plscmap0a", "plplot_8h.html#a9eb0eb1c2f850b6df2dc5fa019182ccb", null ],
    [ "plscmap0n", "plplot_8h.html#a5fad0388a072d5fe94c79a9d966917cc", null ],
    [ "plscmap1", "plplot_8h.html#a7dea99d52e16149018e6044a668b203c", null ],
    [ "plscmap1_range", "plplot_8h.html#aa7f34554ad31df21ff38f87bfa1b0841", null ],
    [ "plscmap1a", "plplot_8h.html#aaa8c0c13333601bcb9689b012a94aba0", null ],
    [ "plscmap1l", "plplot_8h.html#a13c57afe3d60a2c660369903240817f8", null ],
    [ "plscmap1la", "plplot_8h.html#ab73094a0ea25ef00e069b53cddb818e0", null ],
    [ "plscmap1n", "plplot_8h.html#a6e9aeabcddf0bdec5551f70f20a4e1d5", null ],
    [ "plscol0", "plplot_8h.html#a2ef1d5ab2485dce98975fccc647c2021", null ],
    [ "plscol0a", "plplot_8h.html#ad838886ed16f9c677fa58a644ea73ee5", null ],
    [ "plscolbg", "plplot_8h.html#a264c437f3da38c3b47c047d13758240c", null ],
    [ "plscolbga", "plplot_8h.html#a78902e8b32c44596e9d6c720db261488", null ],
    [ "plscolor", "plplot_8h.html#ab837eb4e96d6b0f586c45260afe9e9df", null ],
    [ "plscompression", "plplot_8h.html#a94c1ba16a7bc8afa6d7a0ea9f1fb4640", null ],
    [ "plsdev", "plplot_8h.html#a77aa8a80f7282107b51afcc7b3447500", null ],
    [ "plsdidev", "plplot_8h.html#ae0a15990db0ea9ff583f95d5cd4e0103", null ],
    [ "plsdimap", "plplot_8h.html#aed24d00600dd572cfbe3cc42192e8fb3", null ],
    [ "plsdiori", "plplot_8h.html#a8ede75c5624fb9d2c58b93a82dc431cf", null ],
    [ "plsdiplt", "plplot_8h.html#abf3b363eca688f47a73398c970d51a6c", null ],
    [ "plsdiplz", "plplot_8h.html#a7e474fa3bd1d447273f5954d1e2d34c4", null ],
    [ "plsdrawmode", "plplot_8h.html#af8400ecbd64fe9661c0b724b17b5c3ad", null ],
    [ "plseed", "plplot_8h.html#ad599920c5536f5b558eb4dea7dd700a2", null ],
    [ "plsesc", "plplot_8h.html#a8861841de6eabf18f8471c21dd655a7d", null ],
    [ "plsetopt", "plplot_8h.html#a899af897dd72e2845334ad1c4ff649da", null ],
    [ "plsfam", "plplot_8h.html#a0930f605f90b352d19731247825df673", null ],
    [ "plsfci", "plplot_8h.html#aededd5e2833d12a61ef5b70ca805fe7f", null ],
    [ "plsfnam", "plplot_8h.html#ae180cc25da7b407dc72577b730b9b9ed", null ],
    [ "plsfont", "plplot_8h.html#ad66be92ad40c6e8cdc4de36d6868020f", null ],
    [ "plshade", "plplot_8h.html#aa864df027d27c705b65e2b1e2170ba0c", null ],
    [ "plshade1", "plplot_8h.html#ac3094aae373d21ad461b961593e9482a", null ],
    [ "plshades", "plplot_8h.html#a939743b6e786099fc3b9e50e5a720c62", null ],
    [ "plslabelfunc", "plplot_8h.html#a9374ca78cec47194d25c5b28533ef688", null ],
    [ "plsmaj", "plplot_8h.html#a0a5e4fdc768d2d28d39a283905f84141", null ],
    [ "plsmem", "plplot_8h.html#a48210ec0693b84b1b09597a53fa2efdf", null ],
    [ "plsmema", "plplot_8h.html#a2da2e157c2bace2d5dd521398f22e144", null ],
    [ "plsmin", "plplot_8h.html#a0be47547451e24fbf650e89a8f1308d1", null ],
    [ "plsori", "plplot_8h.html#a142243bf747c657b25201e741e675089", null ],
    [ "plspage", "plplot_8h.html#a905adcdc76976608d1f6af6e0ea8b10e", null ],
    [ "plspal0", "plplot_8h.html#a578e453aec6f0692a2160ab015ac81aa", null ],
    [ "plspal1", "plplot_8h.html#a4f6c2e7087a90e1dda2b194fe66b4065", null ],
    [ "plspause", "plplot_8h.html#a5333bb0bbf12db5f7303f69b8e4c58ed", null ],
    [ "plsstrm", "plplot_8h.html#ab6578e4880073bcd25fb1d5f7125271d", null ],
    [ "plssub", "plplot_8h.html#aff7b8a2809bdc37f766ae777a89d5b64", null ],
    [ "plssym", "plplot_8h.html#ab8057c70946a9e6357c50178c537cd88", null ],
    [ "plstar", "plplot_8h.html#ae795074b5837df727db082cf49a59c4e", null ],
    [ "plstart", "plplot_8h.html#af495818ad5ce1a5afb98d50fe5a95aaa", null ],
    [ "plstransform", "plplot_8h.html#a0e12f03add5dfe781dab30b3817a116c", null ],
    [ "plstring", "plplot_8h.html#a8c665c48bec2c47ea610d98600453b4d", null ],
    [ "plstring3", "plplot_8h.html#a5156dbb2750cd9e45d2de503b9e39d84", null ],
    [ "plstripa", "plplot_8h.html#a487121ddd3dee88385c7841b75502cc8", null ],
    [ "plstripc", "plplot_8h.html#aab9117fdcdd1327a94f8a32f89be810b", null ],
    [ "plstripd", "plplot_8h.html#a3b06951ff31673107f1f88c611b723d9", null ],
    [ "plstyl", "plplot_8h.html#ab1a82727605f3794755981ad693b2133", null ],
    [ "plsurf3d", "plplot_8h.html#a5ccc68e01fcc16286fda4815a7eff4eb", null ],
    [ "plsurf3dl", "plplot_8h.html#a5e786eb34f1ad0eae80402a7bb8b92ab", null ],
    [ "plsvect", "plplot_8h.html#ab17ca34b9b4dda280c00166a5ed2e8ab", null ],
    [ "plsvpa", "plplot_8h.html#a6403edf5da958ee28512503a868b1f03", null ],
    [ "PLSWIN_DEVICE", "plplot_8h.html#a8751bd040cbe7a7601a3f3a74d79ba3d", null ],
    [ "PLSWIN_WORLD", "plplot_8h.html#a5c7f09c95ab94bc5c7c06ec219bb5a99", null ],
    [ "plsxax", "plplot_8h.html#af49979ee1a133453f970f89772df0daf", null ],
    [ "plsyax", "plplot_8h.html#a25ef9eb433e86adbe69ef5458bce1f03", null ],
    [ "plsym", "plplot_8h.html#aa95f3ab43f2edf1400bd98e434392e37", null ],
    [ "plszax", "plplot_8h.html#a47e364638c640e4a93f9335bf2a4d803", null ],
    [ "pltext", "plplot_8h.html#a8b2ab295a0e8d18f34c91722e2748bd6", null ],
    [ "PLTEXT_BACKCHAR", "plplot_8h.html#aa6b09e6214ceb51738d8480ac42c3ec2", null ],
    [ "PLTEXT_FONTCHANGE", "plplot_8h.html#a8d63b6dbaa221c02421f03349e7a18ea", null ],
    [ "PLTEXT_OVERLINE", "plplot_8h.html#a4042cf40f8c5a41459a50f99b6808832", null ],
    [ "PLTEXT_SUBSCRIPT", "plplot_8h.html#a963198b4f7a6e85e2c3136be836a3f88", null ],
    [ "PLTEXT_SUPERSCRIPT", "plplot_8h.html#a22531a3d640ce1c79aab88ec134e1073", null ],
    [ "PLTEXT_UNDERLINE", "plplot_8h.html#af414e60bec2c568dd1f0fe8819865ce7", null ],
    [ "pltimefmt", "plplot_8h.html#a1cec82073afe1eb3610ac8936d9c2fdc", null ],
    [ "plvasp", "plplot_8h.html#a5e8ad8da9112ac06cf73ec865bd2d47d", null ],
    [ "plvect", "plplot_8h.html#a1e884ebd81d68f044ec60469e5e6e6e9", null ],
    [ "plvpas", "plplot_8h.html#a1105d0f36f07fea5fa5b7f1831bc9b8f", null ],
    [ "plvpor", "plplot_8h.html#afa8384d804834f433e07b3c78999a984", null ],
    [ "plvsta", "plplot_8h.html#ac2bcfdab21636a4f8d60c62c43a3c311", null ],
    [ "plw3d", "plplot_8h.html#a6788ee6ca54b0952a8d52f4e5a0ee883", null ],
    [ "plwidth", "plplot_8h.html#a599c15e2e2029f6a2506f0eb03659d36", null ],
    [ "plwind", "plplot_8h.html#ae6cd7548ef5c833e9f97d9176f229d46", null ],
    [ "plxormod", "plplot_8h.html#a52d7f0be5aab44f2db35c627e9a19688", null ],
    [ "SURF_CONT", "plplot_8h.html#acaa655ac92eaccb02b6b93a739499bcc", null ],
    [ "TOP_CONT", "plplot_8h.html#acb12e9a8db273a14ab03715241e88f1a", null ],
    [ "ZEROW2B", "plplot_8h.html#a71153fa058b1bcf36903c89f7b4b2a3f", null ],
    [ "ZEROW2D", "plplot_8h.html#a002b0cf69472088a40a625edb532fd52", null ],
    [ "PLBOOL", "plplot_8h.html#aeaedd6596f4fb4446c7fd5ad8f0e9673", null ],
    [ "PLF2OPS", "plplot_8h.html#a8073ceeb1a43c3988d0f750cbf080c1c", null ],
    [ "PLFLT", "plplot_8h.html#a245c0090f1fa5e95a4ed3522975dcbf3", null ],
    [ "PLINT", "plplot_8h.html#ad703d3a4f671fdd34ec71f3480f6af2d", null ],
    [ "PLINT64", "plplot_8h.html#a75b290585084690535ae97d74b07b570", null ],
    [ "PLPointer", "plplot_8h.html#ae1d5cf832d1a16ecbacbf5eb4bf5e8f1", null ],
    [ "PLUINT", "plplot_8h.html#a6d6b24fb8596cddc72a21a37cbda14e2", null ],
    [ "PLUNICODE", "plplot_8h.html#a1d3c883be63b6e7855f5bc7ad5212915", null ],
    [ "c_pl_setcontlabelformat", "plplot_8h.html#ab92ad7ccd9f1667f27dbc4a9d07f8864", null ],
    [ "c_pl_setcontlabelparam", "plplot_8h.html#a487a1e2265297e29a1538db001744f83", null ],
    [ "c_pladv", "plplot_8h.html#a8a327be272177954338a43a173a8fdb5", null ],
    [ "c_plarc", "plplot_8h.html#aa4edd532f3768f7d88bf4643e448d203", null ],
    [ "c_plaxes", "plplot_8h.html#a78ccbb94e7ab8f2af90acad87088a8af", null ],
    [ "c_plbin", "plplot_8h.html#aa78836f3e7b2d7290a890e46d109052d", null ],
    [ "c_plbop", "plplot_8h.html#accdeaeb65542509d2b8f827266b54982", null ],
    [ "c_plbox", "plplot_8h.html#ac4e2f3dfbff816b3c5fd52197a6453e5", null ],
    [ "c_plbox3", "plplot_8h.html#adcf09a37f50a8044cece162ed5fe9f88", null ],
    [ "c_plbtime", "plplot_8h.html#a4b6bc27aa31006f5a3d48afa09e72e95", null ],
    [ "c_plcalc_world", "plplot_8h.html#a833b008651bdec96a0283f232564eb89", null ],
    [ "c_plclear", "plplot_8h.html#a91c77a69b1de6d6dea80a8b57f1c3292", null ],
    [ "c_plcol0", "plplot_8h.html#a56f6ef6a76c18a7b7b9d2c891d1467be", null ],
    [ "c_plcol1", "plplot_8h.html#a5ada6ff695ce184c11be47def6dae0a6", null ],
    [ "c_plcolorbar", "plplot_8h.html#ac50232f7a090cdafbb8513b4fd717d2c", null ],
    [ "c_plconfigtime", "plplot_8h.html#a5f35b5400d68ae1ebe6418c5bec5052c", null ],
    [ "c_plcont", "plplot_8h.html#a03a658413a59fa7a234ef095bd7a56bd", null ],
    [ "c_plcpstrm", "plplot_8h.html#ad16c39cffa39e594adba42654a95b698", null ],
    [ "c_plctime", "plplot_8h.html#a963faaa11f0287a0760a6d2f6440be9d", null ],
    [ "c_plend", "plplot_8h.html#a4ab1fe008a7495add8bb292f79806ead", null ],
    [ "c_plend1", "plplot_8h.html#a1a5146bbedba53c0ce7fd661d0424f61", null ],
    [ "c_plenv", "plplot_8h.html#a23b6e27e49270223a087483456992753", null ],
    [ "c_plenv0", "plplot_8h.html#adb576c92128ae8b6b031c12ac15a5e1b", null ],
    [ "c_pleop", "plplot_8h.html#a8859fcac8c131dfc61b767b13540387d", null ],
    [ "c_plerrx", "plplot_8h.html#a5ede5a31b97e055407d25bcc0b62bb83", null ],
    [ "c_plerry", "plplot_8h.html#a0907c0cb5767bbe13e24703cc5532ec2", null ],
    [ "c_plfamadv", "plplot_8h.html#a02ad120a9efe2cb42033f3a3f4aa1ce9", null ],
    [ "c_plfill", "plplot_8h.html#a4914542b590fa82badc11bbac6e18dbc", null ],
    [ "c_plfill3", "plplot_8h.html#a9a3ed081aff3bb99f79b07280b6f6888", null ],
    [ "c_plflush", "plplot_8h.html#a97beafec282968a52d99a75b93accc29", null ],
    [ "c_plfont", "plplot_8h.html#ab314b1eb2abdc661c87b988cf1862a88", null ],
    [ "c_plfontld", "plplot_8h.html#ab1801dd8db40f4262d7265a15710d987", null ],
    [ "c_plgchr", "plplot_8h.html#af31374783fde33b7e3fa15b6679e15fb", null ],
    [ "c_plgcmap1_range", "plplot_8h.html#ad8f614c4935c2b774b8aa4fb28f71486", null ],
    [ "c_plgcol0", "plplot_8h.html#a38283d88f36f8dbe8d942d60d5227d8e", null ],
    [ "c_plgcol0a", "plplot_8h.html#af1bafa6196b1dfc71364dc9c1040d855", null ],
    [ "c_plgcolbg", "plplot_8h.html#a5fd0418a0e3335ee28f5a984e3104e2c", null ],
    [ "c_plgcolbga", "plplot_8h.html#a21bcaa00e35eb1a65e309a56b6a56baf", null ],
    [ "c_plgcompression", "plplot_8h.html#a8abdea275f7a74f24f507d07835b87df", null ],
    [ "c_plgdev", "plplot_8h.html#a7bfcd88ba0586868b1e6a306416d9f64", null ],
    [ "c_plgdidev", "plplot_8h.html#aa7e7def3ecb7f2a9fb725c41f47b48b9", null ],
    [ "c_plgdiori", "plplot_8h.html#aabb741c2faedfbdd90a829acd8902bef", null ],
    [ "c_plgdiplt", "plplot_8h.html#a5f22415724d01e7a214bb2725aeb6305", null ],
    [ "c_plgdrawmode", "plplot_8h.html#af320bdd8254937cf5f5fff6379e366ad", null ],
    [ "c_plgfam", "plplot_8h.html#a5fbc82655bdaa77d0983eb4fa2e738d4", null ],
    [ "c_plgfci", "plplot_8h.html#a1c212bf6b83b4a7171a9a90dc7348b70", null ],
    [ "c_plgfnam", "plplot_8h.html#a5fa15c697b899966bfbd8587a70f5296", null ],
    [ "c_plgfont", "plplot_8h.html#ad12c98127135c4d1c4479e4a07a350f0", null ],
    [ "c_plglevel", "plplot_8h.html#a018a9a116388d72e857009e874462d65", null ],
    [ "c_plgpage", "plplot_8h.html#a8ade125e6a2f739eb0710f1f24f6ed96", null ],
    [ "c_plgra", "plplot_8h.html#a20f4029e24d5d3299dd3d2136afc572b", null ],
    [ "c_plgradient", "plplot_8h.html#a3e1325fa507566d1cb4dc33907710f7a", null ],
    [ "c_plgriddata", "plplot_8h.html#a387cce59d30085fe69a8687e463143d3", null ],
    [ "c_plgspa", "plplot_8h.html#affaa89bc162c978596113da648b7d2c6", null ],
    [ "c_plgstrm", "plplot_8h.html#afdc85148e6a8778038c0ab1c44dae0a9", null ],
    [ "c_plgver", "plplot_8h.html#a80cf7995d221d6a4a08dfa6f74d5e5c1", null ],
    [ "c_plgvpd", "plplot_8h.html#a0fb65308985fb0eb897556236ff01b3c", null ],
    [ "c_plgvpw", "plplot_8h.html#a6e1c6d382c47753860eee10186c12cae", null ],
    [ "c_plgxax", "plplot_8h.html#a03cb3367262ac01f01743bd4490ac3f4", null ],
    [ "c_plgyax", "plplot_8h.html#a834c1a87a0663c412e12e17104f1c13d", null ],
    [ "c_plgzax", "plplot_8h.html#aaca6b435455750c229db7c4a2deb1eda", null ],
    [ "c_plhist", "plplot_8h.html#a26925a9320f8c3a0f665a714b47812e9", null ],
    [ "c_plhlsrgb", "plplot_8h.html#a041bb9d5bcab9d063e7353875d89380c", null ],
    [ "c_plimage", "plplot_8h.html#af578d63c522e8cd1ded1915a0cb59656", null ],
    [ "c_plimagefr", "plplot_8h.html#a1aad80d9375a8660287d91fd2cdb31fc", null ],
    [ "c_plinit", "plplot_8h.html#a16ca877b784c3f1afa2157e7b01c9f09", null ],
    [ "c_pljoin", "plplot_8h.html#ae41b66e619fb441dae94b8fe9c7de1e7", null ],
    [ "c_pllab", "plplot_8h.html#a5e1594eab38eb9ecb9ae8b9ec2e4bff6", null ],
    [ "c_pllegend", "plplot_8h.html#a2fd1c8071a2f6b3631cea49cf6233bdd", null ],
    [ "c_pllightsource", "plplot_8h.html#a64222d2e573b3f5e467cbbc55f16d3f6", null ],
    [ "c_plline", "plplot_8h.html#a02f8dd9569ed70fca023e7a6dc9b5620", null ],
    [ "c_plline3", "plplot_8h.html#aaac706424e86b2f7e58afda2d5e41910", null ],
    [ "c_pllsty", "plplot_8h.html#a317c00e1dc4960ac3aa3181ffce231a6", null ],
    [ "c_plmap", "plplot_8h.html#a9391038c1678595134892ff48cbb151e", null ],
    [ "c_plmapfill", "plplot_8h.html#a38b398f721fea3e44a59a8fa6bb51e6f", null ],
    [ "c_plmapline", "plplot_8h.html#aae0c48c339d13839fbbb9da7200a30cc", null ],
    [ "c_plmapstring", "plplot_8h.html#a1dc91678b27b6a92e2c20053324025e6", null ],
    [ "c_plmaptex", "plplot_8h.html#a0c62c3dab9c7d5e1d277a9ef116fa255", null ],
    [ "c_plmeridians", "plplot_8h.html#a6ada49386576a255cb1d7e27a152e111", null ],
    [ "c_plmesh", "plplot_8h.html#a618d08727a1d07ebccca591e3201181e", null ],
    [ "c_plmeshc", "plplot_8h.html#a2969d7142ae7ef0ec919382c5bd192c9", null ],
    [ "c_plmkstrm", "plplot_8h.html#a7b72daf54749d4fc50530bd0078bd647", null ],
    [ "c_plmtex", "plplot_8h.html#abff0987d28ded2f6b07854ba340fb36c", null ],
    [ "c_plmtex3", "plplot_8h.html#ad0f7988e3ef74e1e6c0645ad838d6f44", null ],
    [ "c_plot3d", "plplot_8h.html#ad6079813e6c40aa46404846b5ccc3369", null ],
    [ "c_plot3dc", "plplot_8h.html#a9c13aae387009efe5b46b46e3a3e78b8", null ],
    [ "c_plot3dcl", "plplot_8h.html#a2082412edea213da94500672b925ce5c", null ],
    [ "c_plparseopts", "plplot_8h.html#a62289eba72af9d3d186007d4b03da3f1", null ],
    [ "c_plpat", "plplot_8h.html#af4e038bb94bb29f091fbe36b2326bd2a", null ],
    [ "c_plpath", "plplot_8h.html#ac947f42e00e129aacc9f4ff3c327cc19", null ],
    [ "c_plpoin", "plplot_8h.html#aee7ffbc6ec6b65acd6549ce85efa00d8", null ],
    [ "c_plpoin3", "plplot_8h.html#a5db14b5420774721a58791df0d2c2d26", null ],
    [ "c_plpoly3", "plplot_8h.html#a81848f61f2dc21d3fa87d2fbe7393418", null ],
    [ "c_plprec", "plplot_8h.html#ab6b43004c739e263fe61d819e6891c8a", null ],
    [ "c_plpsty", "plplot_8h.html#a743018ee685c7586c37d0b9102ed0d39", null ],
    [ "c_plptex", "plplot_8h.html#a9c4f52922e3e2a9bb84947fdd6c2781e", null ],
    [ "c_plptex3", "plplot_8h.html#a3e4747e742bbbf1f5581a7e9d3461035", null ],
    [ "c_plrandd", "plplot_8h.html#acf3655ca771545e49a3d28edcef394f0", null ],
    [ "c_plreplot", "plplot_8h.html#a54683e3343102a1ea4cf61fcaef13a8f", null ],
    [ "c_plrgbhls", "plplot_8h.html#a032c66c4cca2e7124baacd3ce912781c", null ],
    [ "c_plschr", "plplot_8h.html#a906b2f2e72c885b9783bbc6342b7c4da", null ],
    [ "c_plscmap0", "plplot_8h.html#a4f8326016609e4686cb339c714116af3", null ],
    [ "c_plscmap0a", "plplot_8h.html#a5dbf015b428b050f37f37ba88fcbeaef", null ],
    [ "c_plscmap0n", "plplot_8h.html#a06233e8a8024f3fe8079de7f607ea73f", null ],
    [ "c_plscmap1", "plplot_8h.html#ac5bd5366e2504980f3da8672d001a2c2", null ],
    [ "c_plscmap1_range", "plplot_8h.html#a15a484127420306e6d1f1c478cf51d59", null ],
    [ "c_plscmap1a", "plplot_8h.html#a9c8a9519937f2c3e7bcbc3c237f68c4a", null ],
    [ "c_plscmap1l", "plplot_8h.html#a03f8c884922878526ded8befd65bb5d4", null ],
    [ "c_plscmap1la", "plplot_8h.html#aad52d3709a1c3ce637d690a15b0932a6", null ],
    [ "c_plscmap1n", "plplot_8h.html#a93963a081b30143656abd1ad77b1e7bc", null ],
    [ "c_plscol0", "plplot_8h.html#a4d5ea8fd667658ed26a7d70ce0fc5264", null ],
    [ "c_plscol0a", "plplot_8h.html#af75af09a57c17101f4b7b5225862b7ae", null ],
    [ "c_plscolbg", "plplot_8h.html#a559e93e1c216351277796748ca0d39d0", null ],
    [ "c_plscolbga", "plplot_8h.html#afa72d07cae36a1535bf8af837aaad4ea", null ],
    [ "c_plscolor", "plplot_8h.html#a5e26e69ae11fc868f67768e88909c3e7", null ],
    [ "c_plscompression", "plplot_8h.html#a9104ebbbc78bdd17139db834e82c832b", null ],
    [ "c_plsdev", "plplot_8h.html#a5427b7d8ceeb6f43def8bf3fc5c40212", null ],
    [ "c_plsdidev", "plplot_8h.html#ae403c84fd74141a2e18396d6a325495a", null ],
    [ "c_plsdimap", "plplot_8h.html#afed985f4d2553562eb32cf1399b61aa5", null ],
    [ "c_plsdiori", "plplot_8h.html#ad2cb5ae88431579cc0f900549613692f", null ],
    [ "c_plsdiplt", "plplot_8h.html#a0dbd7c3db8404977b0793c8341ceb97f", null ],
    [ "c_plsdiplz", "plplot_8h.html#aae802248246b9571c66dff1563a4131a", null ],
    [ "c_plsdrawmode", "plplot_8h.html#a00bf7735eb2174bc163fdf623ac7ea16", null ],
    [ "c_plseed", "plplot_8h.html#a1e607017d84ca2ba0425c77ca7aeb87b", null ],
    [ "c_plsesc", "plplot_8h.html#a2ce235ed573c83efff9f02a696a555ee", null ],
    [ "c_plsetopt", "plplot_8h.html#a8147a66b10fe9c3a80206bad403fd442", null ],
    [ "c_plsfam", "plplot_8h.html#ab3d16a3db91caab121bcb9ce80546fba", null ],
    [ "c_plsfci", "plplot_8h.html#a074ce37141f38208e2d25ce5bb3a785b", null ],
    [ "c_plsfnam", "plplot_8h.html#afa8e0eb91366606acea7efda5c5d1b58", null ],
    [ "c_plsfont", "plplot_8h.html#a6393d02708ce42194302ccf3b94edf47", null ],
    [ "c_plshade", "plplot_8h.html#a681c832685b8bb75faf9e58f37fdf394", null ],
    [ "c_plshade1", "plplot_8h.html#aef38afccf5f7904554bd7c3cb60f3787", null ],
    [ "c_plshades", "plplot_8h.html#a3404cc5e4f32706913920ff6caa8b345", null ],
    [ "c_plslabelfunc", "plplot_8h.html#a3f1f502a0174f82c0308ef96e915281c", null ],
    [ "c_plsmaj", "plplot_8h.html#a1c011f9eeab7ca11a5de4f2afdc2b501", null ],
    [ "c_plsmem", "plplot_8h.html#a60dac657e19f687d66d83ce4c2f9b16c", null ],
    [ "c_plsmema", "plplot_8h.html#a4abe74bf62df2002dc2f6a2c3b6e4306", null ],
    [ "c_plsmin", "plplot_8h.html#afaa43df242c2a6166072b2cc3cf1d1a2", null ],
    [ "c_plsori", "plplot_8h.html#ae92f904189306eb1dc8f1b6641bd3c6b", null ],
    [ "c_plspage", "plplot_8h.html#a993d2bc54f3dd8d7432fe9e2d8ce1b09", null ],
    [ "c_plspal0", "plplot_8h.html#ab61c4c1b39b7e088ddd2a18de8148629", null ],
    [ "c_plspal1", "plplot_8h.html#aa43280e5f4cf5321dd7f552320c82b32", null ],
    [ "c_plspause", "plplot_8h.html#aedc6099dad1ae3e4f444b76a28e06b9a", null ],
    [ "c_plsstrm", "plplot_8h.html#a3cae7c0e783e917bd5d2c25adfdce6fd", null ],
    [ "c_plssub", "plplot_8h.html#ab23fbc49ed42a65bc6d9f51321d2497d", null ],
    [ "c_plssym", "plplot_8h.html#a940a97b378a847bd9699d0e18162d57e", null ],
    [ "c_plstar", "plplot_8h.html#a1690af1bfe3d5c00784fdb9e68d830f9", null ],
    [ "c_plstart", "plplot_8h.html#ae16e0aaab9234c5795aa15744af4ace8", null ],
    [ "c_plstransform", "plplot_8h.html#a4deb0eb1857f5d518851ec1f41528d36", null ],
    [ "c_plstring", "plplot_8h.html#ad187ebae694794eb493a251794f1b70d", null ],
    [ "c_plstring3", "plplot_8h.html#a449b09356e2565fc88b2be19bef4fe03", null ],
    [ "c_plstripa", "plplot_8h.html#a7635fe351043aa7138a17a7d4b7ba2a4", null ],
    [ "c_plstripc", "plplot_8h.html#aad03d002cf1ebb356af1c784964eff0d", null ],
    [ "c_plstripd", "plplot_8h.html#a46d05136dd3eafedef0aab7012cfaacb", null ],
    [ "c_plstyl", "plplot_8h.html#ab8a6f4438be256864247f5e6fe3dfdeb", null ],
    [ "c_plsurf3d", "plplot_8h.html#a0566ff5bf7f1e6aecc25caf69d022c7f", null ],
    [ "c_plsurf3dl", "plplot_8h.html#a63be92c6f128b3b6300822742ea57767", null ],
    [ "c_plsvect", "plplot_8h.html#a4e4072e40ff8a7127801a00b3a9aa281", null ],
    [ "c_plsvpa", "plplot_8h.html#a56d8a17aa2d0a673c802ea948abcdc1c", null ],
    [ "c_plsxax", "plplot_8h.html#a6dcf30171cd60db19a3dbf5bc78e3aae", null ],
    [ "c_plsyax", "plplot_8h.html#a3603d38d28846b15c54a114afdfb28c1", null ],
    [ "c_plsym", "plplot_8h.html#ac6b4b7fdbd26ae0db26f8f656e534680", null ],
    [ "c_plszax", "plplot_8h.html#ae4e2f908751b0a68b5bc599a2e8d50a4", null ],
    [ "c_pltext", "plplot_8h.html#a94c1af262a2855684ddeeea0d13e3fa5", null ],
    [ "c_pltimefmt", "plplot_8h.html#a3e11f5860e12ba7e52f23c9e6eb4c987", null ],
    [ "c_plvasp", "plplot_8h.html#a6d0c2a4be40790e91824ad0b7bac0bec", null ],
    [ "c_plvect", "plplot_8h.html#a8c3439b34e0df4088dfc38819b20e17c", null ],
    [ "c_plvpas", "plplot_8h.html#abd8a7e0ae9bb0da76807e7e0bf93e3a4", null ],
    [ "c_plvpor", "plplot_8h.html#a5fd547420fef9e958c4026bc2e9c4898", null ],
    [ "c_plvsta", "plplot_8h.html#ad6443e9ab2395017d048b8efb06e2ee2", null ],
    [ "c_plw3d", "plplot_8h.html#a44e37b421e4b094322c520057dcd317d", null ],
    [ "c_plwidth", "plplot_8h.html#a35b056d50ccc18dab5832a99268e04ef", null ],
    [ "c_plwind", "plplot_8h.html#a02525a7edb3a826dc05004ed517263b9", null ],
    [ "c_plxormod", "plplot_8h.html#acc9adb6ab2f3b1b60db01825dc038a31", null ],
    [ "pl_cmd", "plplot_8h.html#a1a7540d4d12635cf9f3b1fad73dff8ab", null ],
    [ "plAlloc2dGrid", "plplot_8h.html#a6ac3f4f3085b37a0fed89c01cdfe401e", null ],
    [ "plClearOpts", "plplot_8h.html#a136e9a1081cda371c3fcc2bb59696a3d", null ],
    [ "pldid2pc", "plplot_8h.html#a29189728d7148b7071ce1417aecd0aa7", null ],
    [ "pldip2dc", "plplot_8h.html#af9475e5f7938a3f6ee55eda7cee8dc19", null ],
    [ "plf2eval", "plplot_8h.html#a15c0460c84d3ca43849040b982d8d69e", null ],
    [ "plf2eval1", "plplot_8h.html#a097a30050fd2bddf928fcec1ec2672a6", null ],
    [ "plf2eval2", "plplot_8h.html#a1c1fe17eb91fd166f952947bcef664c0", null ],
    [ "plf2evalr", "plplot_8h.html#a13b48a9789c737d4a5486e4105df1de8", null ],
    [ "plf2ops_c", "plplot_8h.html#a817448e6ec06fc4af7468c0d0a08883d", null ],
    [ "plf2ops_grid_c", "plplot_8h.html#af3e49f0ef356aa28b7f44037f26bd119", null ],
    [ "plf2ops_grid_col_major", "plplot_8h.html#a104755ff623ecf34afc6948186c67177", null ],
    [ "plf2ops_grid_row_major", "plplot_8h.html#a7f85022be841ae07b70b1da84b41b1aa", null ],
    [ "plfcont", "plplot_8h.html#a9f5755bdd03adc20203ddf0bfa90ce1d", null ],
    [ "plfgriddata", "plplot_8h.html#ab7f9123b793fc96897eede04f7688666", null ],
    [ "plfimage", "plplot_8h.html#a5ad593174d50795f89c68316e4ad8479", null ],
    [ "plfimagefr", "plplot_8h.html#a7a97f69b45ccae543005319519da7de0", null ],
    [ "plFindCommand", "plplot_8h.html#a73a6f8a34991958fdaba0daf37255539", null ],
    [ "plFindName", "plplot_8h.html#a6dade9d7cc005d1657ab9c81e531693f", null ],
    [ "plfmesh", "plplot_8h.html#afc236a6a9e6109548e113d6a28b3f736", null ],
    [ "plfmeshc", "plplot_8h.html#a81c72cc5974bb3c06f2468ee0b8e237f", null ],
    [ "plfplot3d", "plplot_8h.html#acb7508ead6179710c4920bdd0aecc20f", null ],
    [ "plfplot3dc", "plplot_8h.html#ae677a6bdc264ed845ffd7a6ad0f6671d", null ],
    [ "plfplot3dcl", "plplot_8h.html#ab7c167736733a885e45cafeb65aac20c", null ],
    [ "plFree2dGrid", "plplot_8h.html#aba3acf43ed3265d44f5bb143903fd5a3", null ],
    [ "plfshade", "plplot_8h.html#ad60ac7db40a535d44761f54179e64ded", null ],
    [ "plfshade1", "plplot_8h.html#a3adf25c17be25ccd0c37b40cc7b5885e", null ],
    [ "plfshades", "plplot_8h.html#a7d33338a8c89fce1f3b3523698af5cb3", null ],
    [ "plfsurf3d", "plplot_8h.html#a416c721a5d6a03161dd17bbff81a8f82", null ],
    [ "plfsurf3dl", "plplot_8h.html#ad268cfa7d32a2e3805deb17d40ea9f15", null ],
    [ "plfvect", "plplot_8h.html#a97acf37f26fe4f4241571bf965fcfdae", null ],
    [ "plgDevs", "plplot_8h.html#aeec376a18355192b3b7909d8bdc50cac", null ],
    [ "plgesc", "plplot_8h.html#a1fddf1a9e60a0374fe84efadb061af10", null ],
    [ "plGetCursor", "plplot_8h.html#a772eea12e90f545a177742aa24fbe365", null ],
    [ "plGetFlt", "plplot_8h.html#ac29c7216ca3031257cdc7af435074652", null ],
    [ "plGetInt", "plplot_8h.html#a33d0354f30ddae270f5858d9c26e7ac8", null ],
    [ "plGetName", "plplot_8h.html#a65b9c9550b66ee563703d3c5f51c4583", null ],
    [ "plgfile", "plplot_8h.html#a98dfabaac9b75da165aa6e7ade475a0f", null ],
    [ "plgFileDevs", "plplot_8h.html#ade57037e4a215706ee10c7d1c6590be2", null ],
    [ "plMergeOpts", "plplot_8h.html#a93bd88e8828e503ba95cc1a3bdc5a10d", null ],
    [ "plMinMax2dGrid", "plplot_8h.html#a12393157b4b24181df64b346a8708f83", null ],
    [ "plOptUsage", "plplot_8h.html#a828ea4bab5bf4b35cb5866e188b81f17", null ],
    [ "plResetOpts", "plplot_8h.html#ad3d858d5c80ab466be7e1993c8d2ee97", null ],
    [ "plsabort", "plplot_8h.html#a6a12df023027d32b69d013754708ebf0", null ],
    [ "plsbopH", "plplot_8h.html#a88ee33a7618aff463079633ccb145e49", null ],
    [ "plsButtonEH", "plplot_8h.html#a361966768bbacf56a799abf06992f7d1", null ],
    [ "plsdevdata", "plplot_8h.html#aac8ab1a019b61633c58c7f5fe9713357", null ],
    [ "plseopH", "plplot_8h.html#a6b6320904fa7f9a952a4c61bbadcf88a", null ],
    [ "plsError", "plplot_8h.html#a07b4540e3e0ceb45b5ce57ebe4f74fc1", null ],
    [ "plSetUsage", "plplot_8h.html#ac0b71244be8e595726b4edf79f8a5580", null ],
    [ "plsexit", "plplot_8h.html#af4aa5b303f4601ff4627a2169202ff84", null ],
    [ "plsfile", "plplot_8h.html#aae38b5a886be8e742373cfa183f0b2a9", null ],
    [ "plsKeyEH", "plplot_8h.html#a11329f8b9214b69d4801de70b41b3740", null ],
    [ "plsxwin", "plplot_8h.html#a41c180a8e3968cb12015b682d40e56d4", null ],
    [ "pltr0", "plplot_8h.html#a8f436e32d8006975f3ca871d2fa9e4f6", null ],
    [ "pltr1", "plplot_8h.html#ae86b2a01d3e79d70c593a2b4d0f1ecae", null ],
    [ "pltr2", "plplot_8h.html#ac18acb9a33e538e602829a532c137933", null ],
    [ "pltr2f", "plplot_8h.html#a89241537360ca41366c0a9504e08e982", null ],
    [ "pltr2p", "plplot_8h.html#a762a1334f97320ac54e95c71da7e49b3", null ],
    [ "plTranslateCursor", "plplot_8h.html#a0a524ebf86467423a7af52e3f86b4d85", null ]
];